@@ -9,7 +9,7 @@ import publication
 
 from jsii.python import classproperty
 
-import aws_cdk.cdk
+import aws_cdk.core
 import aws_cdk.region_info
 __all__ = []
 
